==> normalize-0.2.3.tar.gz: test/query/multiple_operations_test.dart <==
import 'package:test/test.dart';
import 'package:gql/language.dart';

import 'package:normalize/normalize.dart';
import '../shared_data.dart';

void main() {
  group('Multiple Operations', () {
    test('With operationName', () {
      final query = parseString('''
        query FirstQuery {
          author {
            id
            __typename
          }
        }

        query TestQuery {
          posts {
            id
            __typename
            author {
              id
              __typename
              name
            }
            title
            comments {
              id
              __typename
              commenter {
                id
                __typename
                name
              }
            }
          }
        }
      ''');

      expect(
        denormalize(
          query: query,
          reader: (dataId) => sharedNormalizedMap[dataId],
          operationName: 'TestQuery',
          addTypename: true,
        ),
        equals(sharedResponse),
      );

      final normalizedResult = {};
      normalize(
        writer: (dataId, value) => normalizedResult[dataId] = value,
        query: query,
        data: sharedResponse,
        operationName: 'TestQuery',
      );

      expect(
        normalizedResult,
        equals(sharedNormalizedMap),
      );
    });

    test('Without operationName', () {
      final query = parseString('''
        query TestQuery {
          posts {
            id
            __typename
            author {
              id
              __typename
              name
            }
            title
            comments {
              id
              __typename
              commenter {
                id
                __typename
                name
              }
            }
          }
        }

        query FirstQuery {
          author {
            id
            __typename
          }
        }
      ''');
      expect(
        denormalize(
            query: query,
            reader: (dataId) => sharedNormalizedMap[dataId],
            addTypename: true),
        equals(sharedResponse),
      );

      final normalizedResult = {};
      normalize(
        writer: (dataId, value) => normalizedResult[dataId] = value,
        query: query,
        data: sharedResponse,
        operationName: 'TestQuery',
      );

      expect(
        normalizedResult,
        equals(sharedNormalizedMap),
      );
    });
  });
}

==> normalize-0.9.1-dev.0.tar.gz: test/query/multiple_operations_test.dart <==
import 'package:test/test.dart';
import 'package:gql/language.dart';

import 'package:normalize/normalize.dart';
import '../shared_data.dart';

void main() {
  group('Multiple Operations', () {
    test('With operationName', () {
      final query = parseString('''
        query FirstQuery {
          author {
            id
          }
        }
        query TestQuery {
          posts {
            id
            author {
              id
              name
            }
            title
            comments {
              id
              commenter {
                id
                name
              }
            }
          }
        }
      ''');

      expect(
        denormalizeOperation(
          document: query,
          read: (dataId) => sharedNormalizedMap[dataId],
          operationName: 'TestQuery',
          addTypename: true,
        ),
        equals(sharedResponse),
      );

      final normalizedResult = {};
      normalizeOperation(
        read: (dataId) => normalizedResult[dataId],
        addTypename: true,
        write: (dataId, value) => normalizedResult[dataId] = value,
        document: query,
        data: sharedResponse,
        operationName: 'TestQuery',
      );

      expect(
        normalizedResult,
        equals(sharedNormalizedMap),
      );
    });

    test('Without operationName', () {
      final query = parseString('''
        query TestQuery {
          posts {
            id
            author {
              id
              name
            }
            title
            comments {
              id
              commenter {
                id
                name
              }
            }
          }
        }

        query FirstQuery {
          author {
            id
          }
        }
      ''');
      expect(
        denormalizeOperation(
          document: query,
          read: (dataId) => sharedNormalizedMap[dataId],
          addTypename: true,
        ),
        equals(sharedResponse),
      );

      final normalizedResult = {};
      normalizeOperation(
        read: (dataId) => normalizedResult[dataId],
        addTypename: true,
        write: (dataId, value) => normalizedResult[dataId] = value,
        document: query,
        data: sharedResponse,
        operationName: 'TestQuery',
      );

      expect(
        normalizedResult,
        equals(sharedNormalizedMap),
      );
    });
  });
}
